@@ -2,10 +2,8 @@
 /*********************************************************************
  *                
  * Filename:      smapidev.c
- * Description:   ThinkPad configuration API for Linux
- * Status:        beta
- * Author:        Bill Mair <bill.mair@bm-soft.com>
- *                Thomas Hood <jdthood@mail.com>
+ * Description:   IBM SMAPI (System Management API) interface functions
+ * Author:        Bill Mair, Thomas Hood
  * Created:       19 July 1999
  *
  * Please report bugs to the author ASAP.
@@ -34,7 +32,7 @@
 #include <linux/unistd.h>
 #include <getopt.h>
 #include <sys/ioctl.h>
-#include <sys/errno.h>
+#include <errno.h>
 #include <linux/types.h>
 #include <stdio.h>
 #include <string.h>
@@ -45,7 +43,7 @@
 
 /****** defines ******/
 
-#define SZ_SMAPIDEV_VERSION "0.8.1"
+#define SZ_SMAPIDEV_VERSION "2.0"
 
 #define SZ_SMAPIDEV_NAME "smapidev"
 
@@ -116,20 +114,6 @@ bcd8_t bcd8_of_byte( byte bThe )
 	return (bTens << 4) | bUnits;
 }
 
-
-/*
- * This function returns the ioctl errno as a negative number 
- */
-int ioctl_thinkpad( int intFiledesc, int intIoctlNum, unsigned long ulongIoctlArg )
-{
-	int intRtn;
-
-	intRtn = ioctl( intFiledesc, intIoctlNum, ulongIoctlArg );
-	if ( intRtn ) return -errno;
-	return 0;
-}
-
-
 /*
  * This function returns the SMAPI BIOS error code if there is one,
  * otherwise the ioctl errno as a negative number
@@ -139,31 +123,7 @@ int ioctl_smapi( int intFiledesc, smapi_ioparm_t *pioparmThe )
 	int intRtn;
 
 	intRtn = ioctl( intFiledesc, IOCTL_SMAPI_REQUEST, pioparmThe );
-	if ( intRtn && errno == ESMAPI_SMB ) return pioparmThe->out.bRc;
-	if ( intRtn ) return -errno;
-	return 0;
-}
-
-/*
- * This function returns the ioctl errno as a negative number 
- */
-int ioctl_superio( int intFiledesc, superio_ioparm_t *pioparmThe )
-{
-	int intRtn;
-
-	intRtn = ioctl( intFiledesc, IOCTL_SUPERIO_REQUEST, pioparmThe );
-	if ( intRtn ) return -errno;
-	return 0;
-}
-
-/*
- * This function returns the ioctl errno as a negative number 
- */
-int ioctl_rtcmosram( int intFiledesc, rtcmosram_ioparm_t *pioparmThe )
-{
-	int intRtn;
-
-	intRtn = ioctl( intFiledesc, IOCTL_RTCMOSRAM_REQUEST, pioparmThe );
+	if ( intRtn && errno == ETHINKPAD_SUBDRIVER ) return pioparmThe->out.bRc;
 	if ( intRtn ) return -errno;
 	return 0;
 }
@@ -185,25 +145,6 @@ int smapidev_GetInfo( smapidev_info_t *pinfoThe )
 
 /*** smapi-module-access functions ***/
 
-int smapidev_GetModuleInfo(
-	int intFiledesc,
-	smapidev_moduleinfo_t *pmoduleinfoThe
-) {
-	int intRtn;
-
-	intRtn = ioctl_thinkpad(
-		intFiledesc,
-		IOCTL_THINKPAD_GETVER,
-		(unsigned long)&(pmoduleinfoThe->szVersion)
-	);
-	if ( intRtn ) return intRtn;
-
-	/*** Make sure that the returned string is terminated ***/
-	pmoduleinfoThe->szVersion[LEN_VERSION_MAX] = '\0';
-
-	return 0;
-}
-
 
 /*
  * The Technical Reference fails to mention that the returned 
@@ -412,7 +353,7 @@ int smapidev_GetSlaveControllerInfo(
 	smapidev_slaveinfo_t *pslaveinfoThe
 ) {
 	smapi_ioparm_t ioparmThe;
-	bcd8_t bcd8High, bcd8Low;
+	bcd8_t bcd8High = 0, bcd8Low = 0;
 	flag_t fInvalidID;
 	int intRtn;
 
@@ -782,3 +723,4 @@ int smapidev_SetPowerExpenditureMode(
 
 	return 0;
 }
+
