@@ -1,6 +1,6 @@
 /***********************************************************************
  *
- * Author: Martin Fluch <mfluch@mathphys.fsk.uni-heidelberg.de>
+ * Author: Martin Fluch
  *
  *     Copyright (c) 1999 Martin Fluch, All rights reserved
  *     
@@ -22,10 +22,14 @@
 
 #include <unistd.h>
 #include <stdlib.h>
+#include <sys/stat.h>
+#include <linux/unistd.h>
 #include <linux/types.h>
+#include <linux/errno.h>
 #include <stdio.h>
 #include <fcntl.h>
 #include <string.h>
+#include <getopt.h>
 
 #include <curses.h>
 #include <menu.h>
@@ -33,15 +37,14 @@
 
 #include "ntpctl.h"
 
-#define SZ_NTPCTL_VERSION "0.8.0"
+#define SZ_NTPCTL_VERSION "3.0"
 
-#define DEFAULT_DEVICE_NAME	"/dev/thinkpad"
 #define MIN_COLS		40
 #define MIN_LINES		15
 
-
-char *device_name=DEFAULT_DEVICE_NAME;
-int device_fd=-1;
+char *device_name;
+int device_fd = -1;
+bool dev_rdonly = FALSE;
 
 int (*configmenuraw[])(struct menuinfo *,int) =
 {
@@ -677,6 +680,7 @@ init_display(void)
 
   attrset(A_BOLD);
   mvaddstr(1,3,"Ncurses ThinkPad Configuration Tool v" SZ_NTPCTL_VERSION );
+  if(dev_rdonly) { addstr(" (read only)"); }
   attrset(A_NORMAL);
   mvhline(3,0,0,COLS);
 
@@ -778,10 +782,13 @@ handle_sig_winch( int intDummy )
  *
  ***********************************************************************/
 
+int fdevice, fhelp;
+
 int
 startup(void)
 {
   int i,x,y;
+  struct stat statBuf;
 
   initscr();
   savetty();
@@ -801,10 +808,40 @@ startup(void)
 
   signal(SIGINT,handle_sig_int);
 
+  if ( stat(device_name, &statBuf) ) {
+    if ( errno == ENOENT ) {
+      if ( fdevice ) { /* user specified a device name */
+        cleanup( "Device does not exist.  Exiting." );
+        exit(-1);
+      } else {
+        /* Maybe it isn't there because we have devfs and module is absent */
+        /* Try: */
+        device_name = "/dev/thinkpad/thinkpad";
+      }
+    } else { /* some other stat error */
+      cleanup( "Can't stat device.  Exiting." );
+      exit(-1);
+    }
+  }
+  if ( statBuf.st_mode & S_IFDIR ) {
+    /* Default device name is a dir */
+    if ( fdevice ) { /* user specified a device name */
+      cleanup( "Can't open device because it is a directory.  Exiting." );
+      exit(-1);
+    } else {
+      /* We're probably using devfs.  Try this */
+      device_name = "/dev/thinkpad/thinkpad";
+    }
+  }
+
   if((device_fd=open(device_name,O_RDWR))==-1)
     {
-      cleanup("Error while opening the device...");
-      return 1;
+      if((device_fd=open(device_name,O_RDONLY))==-1)
+        {
+          cleanup("Error while opening device.  Exiting.");
+          exit(-1);
+        }                                                                       
+      dev_rdonly=TRUE;
     }
 
   for(i=0;i<CONFIGMENUSIZE;i++) 
@@ -861,13 +898,48 @@ startup(void)
  *
  ***********************************************************************/
 
+// int opterr, optopt; /* unused getopt feedback variables */
+int optind;   /* getopt feedback variable: index of the option in argv */
+char *optarg; /* getopt feedback variable: pointer to the argument string of the option */
+struct option asoMyLongopts[] = {
+  { "help", no_argument, &fhelp, 1 },
+  { "device", required_argument, &fdevice, 1 },
+  { 0, 0, 0, 0 }
+};
+
+
 int 
-main(int argcUnused, char *argvUnused[])
+main(int argc, char *argv[])
 {
   int running=TRUE;
   int key;
   int display_help=TRUE;
- 
+  char *pchOpts="";
+  char chRtn;
+  int iasoCur;
+
+  device_name = "/dev/thinkpad";
+
+  while(
+    (chRtn = getopt_long_only(argc, argv, pchOpts, asoMyLongopts, &iasoCur )) != EOF
+  ) {
+    if ( chRtn == '?' || chRtn == '-' ) {
+      /* unrecognized option or missing argument */
+      fprintf( stderr, "Error scanning options.  Try 'ntpctl --help'.\n" );
+      exit(-1);
+    }
+    if ( optarg == NULL ) continue; /* with while loop */
+    /* option has an argument */
+    if ( asoMyLongopts[iasoCur].flag == &fdevice ) {
+      sscanf( optarg, "%as", &device_name );
+    }
+  }
+
+  if ( fhelp ) {
+    printf( "Usage: ntpctl [--help] [--device=<name>]\n" );
+    exit(0);
+  }
+
   if(startup()) return 1;
 
   while(running)
